'''OpenGL extension NV.occlusion_query

This module customises the behaviour of the 
OpenGL.raw.GL.NV.occlusion_query to provide a more 
Python-friendly API

Overview (from the spec)
	
	The HP_occlusion_test extension defines a mechanism whereby an
	application can query the visibility of an object, where "visible"
	means that at least one pixel passes the depth and stencil tests.
	
	The HP extension has two major shortcomings.
	
	- It returns the result as a simple GL_TRUE/GL_FALSE result, when in
	  fact it is often useful to know exactly how many pixels passed.
	- It provides only a simple "stop-and-wait" model for using multiple
	  queries.  The application begins an occlusion test and ends it;
	  then, at some later point, it asks for the result, at which point
	  the driver must stop and wait until the result from the previous
	  test is back before the application can even begin the next one.
	  This is a very simple model, but its performance is mediocre when
	  an application wishes to perform many queries, and it eliminates
	  most of the opportunites for parallelism between the CPU and GPU.
	
	This extension solves both of those problems.  It returns as its
	result the number of pixels that pass, and it provides an interface
	conceptually similar to that of NV_fence that allows applications to
	issue many occlusion queries before asking for the result of any one.
	As a result, they can overlap the time it takes for the occlusion
	query results to be returned with other, more useful work, such as
	rendering other parts of the scene or performing other computations
	on the CPU.
	
	There are many situations where a pixel count, rather than a boolean
	result, is useful.
	
	- If the visibility test is an object bounding box being used to
	  decide whether to skip the object, sometimes it can be acceptable,
	  and beneficial to performance, to skip an object if less than some
	  threshold number of pixels could be visible.
	- Knowing the number of pixels visible in the bounding box may also
	  help decide what level of detail a model should be drawn with.  If
	  only a few pixels are visible, a low-detail model may be
	  acceptable.  In general, this allows level-of-detail mechanisms to
	  be slightly less ad hoc.
	- "Depth peeling" techniques, such as order-independent transparency,
	  would typically like to know when to stop rendering more layers; it
	  is difficult to come up with a way to determine a priori how many
	  layers to use.  A boolean count allows applications to stop when
	  more layers will not affect the image at all, but this will likely
	  be unacceptable for performance, with minimal gains to image
	  quality.  Instead, it makes more sense to stop rendering when the
	  number of pixels goes below a threshold; this should provide better
	  results than any of these other algorithms.
	- Occlusion queries can be used as a replacement for glReadPixels of
	  the depth buffer to determine whether, say, a light source is
	  visible for the purposes of a lens flare effect or a halo to
	  simulate glare.  Pixel counts allow you to compute the percentage
	  of the light source that is visible, and the brightness of these
	  effects can be modulated accordingly.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/occlusion_query.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.occlusion_query import *
from OpenGL.raw.GL.NV.occlusion_query import _EXTENSION_NAME

def glInitOcclusionQueryNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGenOcclusionQueriesNV=wrapper.wrapper(glGenOcclusionQueriesNV).setOutput(
    'ids',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
# INPUT glDeleteOcclusionQueriesNV.ids size not checked against n
glDeleteOcclusionQueriesNV=wrapper.wrapper(glDeleteOcclusionQueriesNV).setInputArraySize(
    'ids', None
)
glGetOcclusionQueryivNV=wrapper.wrapper(glGetOcclusionQueryivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetOcclusionQueryuivNV=wrapper.wrapper(glGetOcclusionQueryuivNV).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''OpenGL extension VERSION.GL_1_5

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_5 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_5.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_1_5 import *
from OpenGL.raw.GL.VERSION.GL_1_5 import _EXTENSION_NAME

def glInitGl15VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGenQueries=wrapper.wrapper(glGenQueries).setOutput(
    'ids',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
# INPUT glDeleteQueries.ids size not checked against n
glDeleteQueries=wrapper.wrapper(glDeleteQueries).setInputArraySize(
    'ids', None
)
glGetQueryiv=wrapper.wrapper(glGetQueryiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetQueryObjectiv=wrapper.wrapper(glGetQueryObjectiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetQueryObjectuiv=wrapper.wrapper(glGetQueryObjectuiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glDeleteBuffers.buffers size not checked against n
glDeleteBuffers=wrapper.wrapper(glDeleteBuffers).setInputArraySize(
    'buffers', None
)
glGenBuffers=wrapper.wrapper(glGenBuffers).setOutput(
    'buffers',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
# INPUT glBufferData.data size not checked against size
glBufferData=wrapper.wrapper(glBufferData).setInputArraySize(
    'data', None
)
# INPUT glBufferSubData.data size not checked against size
glBufferSubData=wrapper.wrapper(glBufferSubData).setInputArraySize(
    'data', None
)
glGetBufferSubData=wrapper.wrapper(glGetBufferSubData).setOutput(
    'data',size=lambda x:(x,),pnameArg='size',orPassIn=True
)
glGetBufferParameteriv=wrapper.wrapper(glGetBufferParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetBufferPointerv=wrapper.wrapper(glGetBufferPointerv).setOutput(
    'params',size=(1,),orPassIn=True
)
### END AUTOGENERATED SECTION
from OpenGL.lazywrapper import lazy as _lazy
from OpenGL.arrays import ArrayDatatype
from OpenGL._bytes import long, integer_types

@_lazy( glBufferData )
def glBufferData( baseOperation, target, size, data=None, usage=None ):
    """Copy given data into the currently bound vertex-buffer-data object

    target -- the symbolic constant indicating which buffer type is intended
    size -- if provided, the count-in-bytes of the array
    data -- data-pointer to be used, may be None to initialize without
        copying over a data-set
    usage -- hint to the driver as to how to set up access to the buffer

    Note: parameter "size" can be omitted, which makes the signature
        glBufferData( target, data, usage )
    instead of:
        glBufferData( target, size, data, usage )
    """
    if usage is None:
        usage = data
        data = size
        size = None
    data = ArrayDatatype.asArray( data )
    if size is None:
        size = ArrayDatatype.arrayByteCount( data )
    return baseOperation( target, size, data, usage )

@_lazy( glBufferSubData )
def glBufferSubData( baseOperation, target, offset, size=None, data=None ):
    """Copy subset of data into the currently bound vertex-buffer-data object

    target -- the symbolic constant indicating which buffer type is intended
    offset -- offset from beginning of buffer at which to copy bytes
    size -- the count-in-bytes of the array (if an int/long), if None,
        calculate size from data, if an array and data is None, use as
        data (i.e. the parameter can be omitted and calculated)
    data -- data-pointer to be used, may be None to initialize without
        copying over a data-set

    Note that if size is not an int/long it is considered to be data
    *iff* data is None
    """
    if size is None:
        if data is None:
            raise TypeError( "Need data or size" )
    elif (not isinstance( size, integer_types)) and (data is None):
        data = size 
        size = None
    try:
        if size is not None:
            size = int( size )
    except TypeError as err:
        if data is not None:
            raise TypeError(
                """Expect an integer size *or* a data-array, not both"""
            )
        data = size
        size = None
    data = ArrayDatatype.asArray( data )
    if size is None:
        size = ArrayDatatype.arrayByteCount( data )
    return baseOperation( target, offset, size, data )

glGetBufferParameteriv = wrapper.wrapper(glGetBufferParameteriv).setOutput(
    "params",(1,), orPassIn=True
)
@_lazy( glGetBufferPointerv )
def glGetBufferPointerv( baseOperation, target, pname, params=None ):
    """Retrieve a ctypes pointer to buffer's data"""
    if params is None:
        size = glGetBufferParameteriv( target, GL_BUFFER_SIZE )
        data = arrays.ArrayDatatype.zeros( (size,), GL_UNSIGNED_BYTE )
        result = baseOperation( target, pname, ctypes.byref( data ) )
        return data
    else:
        return baseOperation( target, pname, params )

@_lazy( glDeleteQueries )
def glDeleteQueries( baseOperation, n, ids=None ):
    if ids is None:
        ids = arrays.GLuintArray.asArray( n )
        n = arrays.GLuintArray.arraySize( ids )
    else:
        ids = arrays.GLuintArray.asArray( ids )
    return baseOperation( n,ids )
@_lazy( glGenQueries )
def glGenQueries( baseOperation, n, ids=None ):
    """Generate n queries, if ids is None, is allocated

    returns array of ids
    """
    if ids is None:
        ids = arrays.GLuintArray.zeros( (n,))
    else:
        ids = arrays.GLuintArray.asArray( ids )
    baseOperation( n, ids )
    return ids

for func in (
    'glGetQueryiv','glGetQueryObjectiv','glGetQueryObjectuiv',
):
    globals()[func] = wrapper.wrapper(globals()[func]).setOutput(
        "params", (1,), orPassIn=True
    )
try:
    del func, glget
except NameError as err:
    pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_indirect_parameters'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_indirect_parameters',error_checker=_errors._error_checker)
GL_PARAMETER_BUFFER_ARB=_C('GL_PARAMETER_BUFFER_ARB',0x80EE)
GL_PARAMETER_BUFFER_BINDING_ARB=_C('GL_PARAMETER_BUFFER_BINDING_ARB',0x80EF)
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLintptr,_cs.GLsizei,_cs.GLsizei)
def glMultiDrawArraysIndirectCountARB(mode,indirect,drawcount,maxdrawcount,stride):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLintptr,_cs.GLintptr,_cs.GLsizei,_cs.GLsizei)
def glMultiDrawElementsIndirectCountARB(mode,type,indirect,drawcount,maxdrawcount,stride):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_APPLE_copy_texture_levels'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_APPLE_copy_texture_levels',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLint,_cs.GLsizei)
def glCopyTextureLevelsAPPLE(destinationTexture,sourceTexture,sourceBaseLevel,sourceLevelCount):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.EGL import _types as _cs
# End users want this...
from OpenGL.raw.EGL._types import *
from OpenGL.raw.EGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'EGL_KHR_reusable_sync'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.EGL,'EGL_KHR_reusable_sync',error_checker=_errors._error_checker)
EGL_CONDITION_SATISFIED_KHR=_C('EGL_CONDITION_SATISFIED_KHR',0x30F6)
EGL_FOREVER_KHR=_C('EGL_FOREVER_KHR',0xFFFFFFFFFFFFFFFF)
# EGL_NO_SYNC_KHR=_C('EGL_NO_SYNC_KHR',((EGLSyncKHR)0))
EGL_SIGNALED_KHR=_C('EGL_SIGNALED_KHR',0x30F2)
EGL_SYNC_FLUSH_COMMANDS_BIT_KHR=_C('EGL_SYNC_FLUSH_COMMANDS_BIT_KHR',0x0001)
EGL_SYNC_REUSABLE_KHR=_C('EGL_SYNC_REUSABLE_KHR',0x30FA)
EGL_SYNC_STATUS_KHR=_C('EGL_SYNC_STATUS_KHR',0x30F1)
EGL_SYNC_TYPE_KHR=_C('EGL_SYNC_TYPE_KHR',0x30F7)
EGL_TIMEOUT_EXPIRED_KHR=_C('EGL_TIMEOUT_EXPIRED_KHR',0x30F5)
EGL_UNSIGNALED_KHR=_C('EGL_UNSIGNALED_KHR',0x30F3)
@_f
@_p.types(_cs.EGLint,_cs.EGLDisplay,_cs.EGLSyncKHR,_cs.EGLint,_cs.EGLTimeKHR)
def eglClientWaitSyncKHR(dpy,sync,flags,timeout):pass
@_f
@_p.types(_cs.EGLSyncKHR,_cs.EGLDisplay,_cs.EGLenum,arrays.GLintArray)
def eglCreateSyncKHR(dpy,type,attrib_list):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSyncKHR)
def eglDestroySyncKHR(dpy,sync):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSyncKHR,_cs.EGLint,arrays.GLintArray)
def eglGetSyncAttribKHR(dpy,sync,attribute,value):pass
@_f
@_p.types(_cs.EGLBoolean,_cs.EGLDisplay,_cs.EGLSyncKHR,_cs.EGLenum)
def eglSignalSyncKHR(dpy,sync,mode):pass



'''OpenGL extension ARB.texture_mirror_clamp_to_edge

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_mirror_clamp_to_edge to provide a more 
Python-friendly API

Overview (from the spec)
	
	ARB_texture_mirror_clamp_to_edge extends the set of texture wrap modes to
	include an additional mode (GL_MIRROR_CLAMP_TO_EDGE) that effectively uses
	a texture map twice as large as the original image in which the additional
	half of the new image is a mirror image of the original image.
	
	This new mode relaxes the need to generate images whose opposite edges
	match by using the original image to generate a matching "mirror image".
	This mode allows the texture to be mirrored only once in the negative
	s, t, and r directions.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_mirror_clamp_to_edge.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_mirror_clamp_to_edge import *
from OpenGL.raw.GL.ARB.texture_mirror_clamp_to_edge import _EXTENSION_NAME

def glInitTextureMirrorClampToEdgeARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension EXT.texture_lod_bias

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_lod_bias to provide a more 
Python-friendly API

Overview (from the spec)
	
	OpenGL computes a texture level-of-detail parameter, called lambda
	in the GL specification, that determines which mipmap levels and
	their relative mipmap weights for use in mipmapped texture filtering.
	
	This extension provides a means to bias the lambda computation
	by a constant (signed) value.  This bias can provide a way to blur
	or pseudo-sharpen OpenGL's standard texture filtering.
	
	This blurring or pseudo-sharpening may be useful for special effects
	(such as depth-of-field effects) or image processing techniques
	(where the mipmap levels act as pre-downsampled image versions).
	On some implementations, increasing the texture lod bias may improve
	texture filtering performance (at the cost of texture bluriness).
	
	The extension mimics functionality found in Direct3D.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_lod_bias.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_lod_bias import *
from OpenGL.raw.GL.EXT.texture_lod_bias import _EXTENSION_NAME

def glInitTextureLodBiasEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_APPLE_object_purgeable'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_APPLE_object_purgeable',error_checker=_errors._error_checker)
GL_BUFFER_OBJECT_APPLE=_C('GL_BUFFER_OBJECT_APPLE',0x85B3)
GL_PURGEABLE_APPLE=_C('GL_PURGEABLE_APPLE',0x8A1D)
GL_RELEASED_APPLE=_C('GL_RELEASED_APPLE',0x8A19)
GL_RETAINED_APPLE=_C('GL_RETAINED_APPLE',0x8A1B)
GL_UNDEFINED_APPLE=_C('GL_UNDEFINED_APPLE',0x8A1C)
GL_VOLATILE_APPLE=_C('GL_VOLATILE_APPLE',0x8A1A)
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetObjectParameterivAPPLE(objectType,name,pname,params):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum)
def glObjectPurgeableAPPLE(objectType,name,option):pass
@_f
@_p.types(_cs.GLenum,_cs.GLenum,_cs.GLuint,_cs.GLenum)
def glObjectUnpurgeableAPPLE(objectType,name,option):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_instruments'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_instruments',error_checker=_errors._error_checker)
GL_INSTRUMENT_BUFFER_POINTER_SGIX=_C('GL_INSTRUMENT_BUFFER_POINTER_SGIX',0x8180)
GL_INSTRUMENT_MEASUREMENTS_SGIX=_C('GL_INSTRUMENT_MEASUREMENTS_SGIX',0x8181)
@_f
@_p.types(_cs.GLint,)
def glGetInstrumentsSGIX():pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLintArray)
def glInstrumentsBufferSGIX(size,buffer):pass
@_f
@_p.types(_cs.GLint,arrays.GLintArray)
def glPollInstrumentsSGIX(marker_p):pass
@_f
@_p.types(None,_cs.GLint)
def glReadInstrumentsSGIX(marker):pass
@_f
@_p.types(None,)
def glStartInstrumentsSGIX():pass
@_f
@_p.types(None,_cs.GLint)
def glStopInstrumentsSGIX(marker):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_viewport_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_viewport_array',error_checker=_errors._error_checker)
GL_DEPTH_RANGE=_C('GL_DEPTH_RANGE',0x0B70)
GL_MAX_VIEWPORTS_NV=_C('GL_MAX_VIEWPORTS_NV',0x825B)
GL_SCISSOR_BOX=_C('GL_SCISSOR_BOX',0x0C10)
GL_SCISSOR_TEST=_C('GL_SCISSOR_TEST',0x0C11)
GL_VIEWPORT=_C('GL_VIEWPORT',0x0BA2)
GL_VIEWPORT_BOUNDS_RANGE_NV=_C('GL_VIEWPORT_BOUNDS_RANGE_NV',0x825D)
GL_VIEWPORT_INDEX_PROVOKING_VERTEX_NV=_C('GL_VIEWPORT_INDEX_PROVOKING_VERTEX_NV',0x825F)
GL_VIEWPORT_SUBPIXEL_BITS_NV=_C('GL_VIEWPORT_SUBPIXEL_BITS_NV',0x825C)
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glDepthRangeArrayfvNV(first,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat)
def glDepthRangeIndexedfNV(index,n,f):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glDisableiNV(target,index):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glEnableiNV(target,index):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLfloatArray)
def glGetFloati_vNV(target,index,data):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum,_cs.GLuint)
def glIsEnablediNV(target,index):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLintArray)
def glScissorArrayvNV(first,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glScissorIndexedNV(index,left,bottom,width,height):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glScissorIndexedvNV(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLfloatArray)
def glViewportArrayvNV(first,count,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glViewportIndexedfNV(index,x,y,w,h):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glViewportIndexedfvNV(index,v):pass



'''OpenGL extension ARB.robust_buffer_access_behavior

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.robust_buffer_access_behavior to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension specifies the behavior of out-of-bounds buffer and array
	accesses. This is an improvement over the existing ARB_robustness
	extension which stated that the application should not crash, but
	the behavior is otherwise undefined. This extension specifies the access
	protection provided by the GL to ensure that out-of-bounds accesses
	cannot read from or write to data not owned by the application. All
	accesses are contained within the buffer object and program area they
	reference. These additional robustness guarantees apply to contexts
	created with the CONTEXT_FLAG_ROBUST_ACCESS_BIT_ARB feature enabled.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/robust_buffer_access_behavior.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.robust_buffer_access_behavior import *
from OpenGL.raw.GL.ARB.robust_buffer_access_behavior import _EXTENSION_NAME

def glInitRobustBufferAccessBehaviorARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_SGIX_fbconfig'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_SGIX_fbconfig',error_checker=_errors._error_checker)
GLX_COLOR_INDEX_BIT_SGIX=_C('GLX_COLOR_INDEX_BIT_SGIX',0x00000002)
GLX_COLOR_INDEX_TYPE_SGIX=_C('GLX_COLOR_INDEX_TYPE_SGIX',0x8015)
GLX_DRAWABLE_TYPE_SGIX=_C('GLX_DRAWABLE_TYPE_SGIX',0x8010)
GLX_FBCONFIG_ID_SGIX=_C('GLX_FBCONFIG_ID_SGIX',0x8013)
GLX_PIXMAP_BIT_SGIX=_C('GLX_PIXMAP_BIT_SGIX',0x00000002)
GLX_RENDER_TYPE_SGIX=_C('GLX_RENDER_TYPE_SGIX',0x8011)
GLX_RGBA_BIT_SGIX=_C('GLX_RGBA_BIT_SGIX',0x00000001)
GLX_RGBA_TYPE_SGIX=_C('GLX_RGBA_TYPE_SGIX',0x8014)
GLX_SCREEN_EXT=_C('GLX_SCREEN_EXT',0x800C)
GLX_WINDOW_BIT_SGIX=_C('GLX_WINDOW_BIT_SGIX',0x00000001)
GLX_X_RENDERABLE_SGIX=_C('GLX_X_RENDERABLE_SGIX',0x8012)
@_f
@_p.types(ctypes.POINTER(_cs.GLXFBConfigSGIX),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int),ctypes.POINTER(_cs.c_int))
def glXChooseFBConfigSGIX(dpy,screen,attrib_list,nelements):pass
@_f
@_p.types(_cs.GLXContext,ctypes.POINTER(_cs.Display),_cs.GLXFBConfigSGIX,_cs.c_int,_cs.GLXContext,_cs.Bool)
def glXCreateContextWithConfigSGIX(dpy,config,render_type,share_list,direct):pass
@_f
@_p.types(_cs.GLXPixmap,ctypes.POINTER(_cs.Display),_cs.GLXFBConfigSGIX,_cs.Pixmap)
def glXCreateGLXPixmapWithConfigSGIX(dpy,config,pixmap):pass
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.GLXFBConfigSGIX,_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXGetFBConfigAttribSGIX(dpy,config,attribute,value):pass
@_f
@_p.types(_cs.GLXFBConfigSGIX,ctypes.POINTER(_cs.Display),ctypes.POINTER(_cs.XVisualInfo))
def glXGetFBConfigFromVisualSGIX(dpy,vis):pass
@_f
@_p.types(ctypes.POINTER(_cs.XVisualInfo),ctypes.POINTER(_cs.Display),_cs.GLXFBConfigSGIX)
def glXGetVisualFromFBConfigSGIX(dpy,config):pass



'''OpenGL extension ARB.half_float_vertex

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.half_float_vertex to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension extends the usage of the half-precision (16-bit) floating-
	point quantities introduced in ARB_half_float_pixel for usage in specifying
	vertex array data.
	
	This extension allows applications to use half-precision floating point data
	when specifying vertices.  This can allow applications to reduce their
	memory footprint, as well as the memory bandwidth required for vertex data.
	
	This extension extends the existing vertex array commands to accept the new
	data type.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/half_float_vertex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.half_float_vertex import *
from OpenGL.raw.GL.ARB.half_float_vertex import _EXTENSION_NAME

def glInitHalfFloatVertexARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Abstraction for the platform-specific code in PyOpenGL

Each supported platform has a module which provides the
specific functionality required to support the base OpenGL 
functionality on that platform.  These modules are 
registered using plugins in the:

    OpenGL.plugin.PlatformPlugin

objects.  To support a new platform you'll need to create
a new PlatformPlugin instance *before* you import 
OpenGL.platform .  Once you have a working platform 
module, please consider contributing it back to the project.

See baseplatform.BasePlatform for the core functionality 
of a platform implementation.  See the various platform 
specific modules for examples to use when porting.
"""
import os, sys
from OpenGL.plugins import PlatformPlugin

def _load( ):
    """Load the os.name plugin for the platform functionality"""
    key = (os.environ.get( 'PYOPENGL_PLATFORM'), sys.platform,os.name)
    plugin  = PlatformPlugin.match( key )
    plugin_class = plugin.load()
    plugin.loaded = True
    # create instance of this platform implementation
    plugin = plugin_class()

    # install into the platform module's namespace now
    plugin.install(globals())
    return plugin

_load()

def types(resultType,*argTypes):
    """Decorator to add returnType, argTypes and argNames to a function"""
    def add_types( function ):
        """Adds the given metadata to the function, introspects var names from declaration"""
        function.resultType = resultType
        function.argTypes = argTypes 
        if hasattr( function, 'func_code' ): # python 2.x
            function.argNames = function.func_code.co_varnames
        else:
            function.argNames = function.__code__.co_varnames
        return function 
    return add_types

def unpack_constants( constants, namespace ):
    """Create constants and add to the namespace"""
    from OpenGL.constant import Constant
    for line in constants.splitlines():
        if line and line.split():
            name,value = line.split()
            namespace[name] = Constant( name, int(value,16) )

def createFunction( function, dll,extension,deprecated=False, error_checker=None ):
    """Allows the more compact declaration format to use the old-style constructor"""
    return nullFunction(
        function.__name__,
        dll or PLATFORM.GL,
        resultType = function.resultType,
        argTypes = function.argTypes,
        doc = None, argNames = function.argNames,
        extension = extension,
        deprecated = deprecated,
        module = function.__module__,
        error_checker = error_checker,
    )



"""Data-type definitions for EGL/GLES"""
import ctypes
pointer = ctypes.pointer

class _Opaque( ctypes.Structure ):
    """An Opaque Structure reference (base class)"""
class _opaque_pointer( ctypes.POINTER( _Opaque ) ):
    _type_ = _Opaque
    @classmethod
    def from_param( cls, value ):
        return ctypes.cast( value, cls )
    @property
    def address( self ):
        return ctypes.addressof( self.contents )
    @property 
    def as_voidp( self ):
        return ctypes.c_voidp( self.address )
    def __hash__(self):
        """Allow these pointers to be used as keys in dictionaries"""
        return self.address
def opaque_pointer_cls( name ):
    """Create an Opaque pointer class for the given name"""
    typ = type( name, (_Opaque,), {} )
    p_typ = type( name+'_pointer', (_opaque_pointer,), {'_type_':typ})
    return p_typ



'''OpenGL extension APPLE.aux_depth_stencil

This module customises the behaviour of the 
OpenGL.raw.GL.APPLE.aux_depth_stencil to provide a more 
Python-friendly API

Overview (from the spec)
	
	Normally, each OpenGL drawable allocates at most one depth buffer and one
	stencil buffer, regardless of how many aux buffers there are.
	
	When the APPLE_aux_depth_stencil extension is used, and the depth buffer
	size is non-zero, the GL silently allocates a separate depth buffer for the
	color buffer and for each aux buffer.  Similarly, if the stencil buffer size
	is non-zero, a separate stencil buffer is allocated for the color buffer and
	each aux buffer.  This extension does not cause separate depth or stencil
	buffers to be allocated for the left and right buffers of a stereo drawable.
	A context with no aux buffers will be unaffected by this extension.  
	
	Switching the draw or read buffer from the color buffer to an aux buffer, or
	switching between two aux buffers, simultaneously switches the associated
	depth and stencil buffers, for drawing or reading.
	
	For example, if an OpenGL context has two aux buffers and non-zero depth
	buffer size, it will have a total of three depth buffers - one associated
	with the color buffer and one associated with each aux buffer.  If that
	context is used to render to AUX0, then to render to AUX1, the changes to
	the depth buffer made by the rendering to AUX1 will not affect the depth
	buffer associated with AUX0, and vice versa.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/APPLE/aux_depth_stencil.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.APPLE.aux_depth_stencil import *
from OpenGL.raw.GL.APPLE.aux_depth_stencil import _EXTENSION_NAME

def glInitAuxDepthStencilAPPLE():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


from OpenGL.raw.GL._types import GLenum,GLboolean,GLsizei,GLint
from OpenGL.raw.osmesa._types import *
from OpenGL.constant import Constant as _C
from OpenGL import platform as _p
import ctypes

def _f( function ):
    return _p.createFunction( 
        function,_p.PLATFORM.OSMesa,
        None,
        error_checker=None
    )

OSMESA_COLOR_INDEX = _C('OSMESA_COLOR_INDEX', 6400)
OSMESA_RGBA = _C('OSMESA_RGBA', 6408)
OSMESA_BGRA = _C('OSMESA_BGRA', 0x1)
OSMESA_ARGB = _C('OSMESA_ARGB', 0x2)
OSMESA_RGB = _C('OSMESA_RGB', 6407)
OSMESA_BGR = _C('OSMESA_BGR',	0x4)
OSMESA_RGB_565 = _C('OSMESA_BGR', 0x5)
OSMESA_ROW_LENGTH = _C('OSMESA_ROW_LENGTH', 0x10)
OSMESA_Y_UP = _C('OSMESA_Y_UP', 0x11)
OSMESA_WIDTH = _C('OSMESA_WIDTH', 0x20)
OSMESA_HEIGHT = _C('OSMESA_HEIGHT', 0x21)
OSMESA_FORMAT = _C('OSMESA_FORMAT', 0x22)
OSMESA_TYPE = _C('OSMESA_TYPE', 0x23)
OSMESA_MAX_WIDTH = _C('OSMESA_MAX_WIDTH', 0x24)
OSMESA_MAX_HEIGHT = _C('OSMESA_MAX_HEIGHT', 0x25)

OSMesaGetCurrentContext = _p.GetCurrentContext

@_f
@_p.types(OSMesaContext,GLenum, OSMesaContext)
def OSMesaCreateContext(format,sharelist): pass

@_f
@_p.types(OSMesaContext,GLenum, GLint, GLint, GLint, OSMesaContext)
def OSMesaCreateContextExt(format, depthBits, stencilBits,accumBits,sharelist ): pass

@_f
@_p.types(None, OSMesaContext)
def OSMesaDestroyContext(ctx): pass

@_f 
@_p.types(GLboolean, OSMesaContext, ctypes.POINTER(None), GLenum, GLsizei, GLsizei )
def OSMesaMakeCurrent( ctx, buffer, type,width,height ): pass

@_f 
@_p.types(None, GLint, GLint )
def OSMesaPixelStore( ctx, buffer, type,width,height ): pass

def OSMesaGetIntegerv(pname):
    value = GLint()
    _p.PLATFORM.GL.OSMesaGetIntegerv(pname, ctypes.byref(value))
    return value.value

def OSMesaGetDepthBuffer(c):
    width, height, bytesPerValue = GLint(), GLint(), GLint()
    buffer = ctypes.POINTER(GLint)()

    if _p.PLATFORM.GL.OSMesaGetDepthBuffer(c, ctypes.byref(width),
                                    ctypes.byref(height),
                                    ctypes.byref(bytesPerValue),
                                    ctypes.byref(buffer)):
        return width.value, height.value, bytesPerValue.value, buffer
    else:
        return 0, 0, 0, None

def OSMesaGetColorBuffer(c):
    # TODO: make output array types which can handle the operation 
    # provide an API to convert pointers + sizes to array instances,
    # e.g. numpy.ctypeslib.as_array( ptr, bytesize ).astype( 'B' ).reshape( height,width )
    width, height, format = GLint(), GLint(), GLint()
    buffer = ctypes.c_void_p()

    if GL.OSMesaGetColorBuffer(c, ctypes.byref(width),
                                    ctypes.byref(height),
                                    ctypes.byref(format),
                                    ctypes.byref(buffer)):
        return width.value, height.value, format.value, buffer
    else:
        return 0, 0, 0, None


__all__ = [
    'OSMesaCreateContext',
    'OSMesaCreateContextExt', 'OSMesaMakeCurrent', 'OSMesaGetIntegerv',
    'OSMesaGetCurrentContext', 'OSMesaDestroyContext', 'OSMesaPixelStore',
    'OSMesaGetDepthBuffer', 'OSMesaGetColorBuffer',
    'OSMESA_COLOR_INDEX', 'OSMESA_RGBA', 'OSMESA_BGRA', 'OSMESA_ARGB',
    'OSMESA_RGB', 'OSMESA_BGR', 'OSMESA_BGR', 'OSMESA_ROW_LENGTH',
    'OSMESA_Y_UP', 'OSMESA_WIDTH', 'OSMESA_HEIGHT', 'OSMESA_FORMAT',
    'OSMESA_TYPE', 'OSMESA_MAX_WIDTH', 'OSMESA_MAX_HEIGHT',
]



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_OES_fixed_point'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_OES_fixed_point',error_checker=_errors._error_checker)
GL_FIXED_OES=_C('GL_FIXED_OES',0x140C)
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glAccumxOES(op,value):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glAlphaFuncxOES(func,ref):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLsizei,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,arrays.GLubyteArray)
def glBitmapxOES(width,height,xorig,yorig,xmove,ymove,bitmap):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glBlendColorxOES(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glClearAccumxOES(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glClearColorxOES(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfixed)
def glClearDepthxOES(depth):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glClipPlanexOES(plane,equation):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glColor3xOES(red,green,blue):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glColor3xvOES(components):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glColor4xOES(red,green,blue,alpha):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glColor4xvOES(components):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glConvolutionParameterxOES(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glConvolutionParameterxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glDepthRangexOES(n,f):pass
@_f
@_p.types(None,_cs.GLfixed)
def glEvalCoord1xOES(u):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glEvalCoord1xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glEvalCoord2xOES(u,v):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glEvalCoord2xvOES(coords):pass
@_f
@_p.types(None,_cs.GLsizei,_cs.GLenum,arrays.GLfixedArray)
def glFeedbackBufferxOES(n,type,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glFogxOES(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glFogxvOES(pname,param):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glFrustumxOES(l,r,b,t,n,f):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glGetClipPlanexOES(plane,equation):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetConvolutionParameterxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glGetFixedvOES(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetHistogramParameterxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetLightxOES(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetLightxvOES(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetMapxvOES(target,query,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glGetMaterialxOES(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetMaterialxvOES(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLfixedArray)
def glGetPixelMapxv(map,size,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetTexEnvxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetTexGenxvOES(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,arrays.GLfixedArray)
def glGetTexLevelParameterxvOES(target,level,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetTexParameterxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLfixed)
def glIndexxOES(component):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glIndexxvOES(component):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glLightModelxOES(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glLightModelxvOES(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glLightxOES(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glLightxvOES(light,pname,params):pass
@_f
@_p.types(None,_cs.GLfixed)
def glLineWidthxOES(width):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glLoadMatrixxOES(m):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glLoadTransposeMatrixxOES(m):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed,_cs.GLfixed,_cs.GLint,_cs.GLint,_cs.GLfixed)
def glMap1xOES(target,u1,u2,stride,order,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed,_cs.GLfixed,_cs.GLint,_cs.GLint,_cs.GLfixed,_cs.GLfixed,_cs.GLint,_cs.GLint,_cs.GLfixed)
def glMap2xOES(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,points):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfixed,_cs.GLfixed)
def glMapGrid1xOES(n,u1,u2):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glMapGrid2xOES(n,u1,u2,v1,v2):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glMaterialxOES(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glMaterialxvOES(face,pname,param):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glMultMatrixxOES(m):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glMultTransposeMatrixxOES(m):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glMultiTexCoord1xOES(texture,s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glMultiTexCoord1xvOES(texture,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed,_cs.GLfixed)
def glMultiTexCoord2xOES(texture,s,t):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glMultiTexCoord2xvOES(texture,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glMultiTexCoord3xOES(texture,s,t,r):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glMultiTexCoord3xvOES(texture,coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glMultiTexCoord4xOES(texture,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glMultiTexCoord4xvOES(texture,coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glNormal3xOES(nx,ny,nz):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glNormal3xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glOrthoxOES(l,r,b,t,n,f):pass
@_f
@_p.types(None,_cs.GLfixed)
def glPassThroughxOES(token):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,arrays.GLfixedArray)
def glPixelMapx(map,size,values):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glPixelStorex(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glPixelTransferxOES(pname,param):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glPixelZoomxOES(xfactor,yfactor):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glPointParameterxOES(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glPointParameterxvOES(pname,params):pass
@_f
@_p.types(None,_cs.GLfixed)
def glPointSizexOES(size):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glPolygonOffsetxOES(factor,units):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray,arrays.GLfixedArray)
def glPrioritizeTexturesxOES(n,textures,priorities):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glRasterPos2xOES(x,y):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glRasterPos2xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glRasterPos3xOES(x,y,z):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glRasterPos3xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glRasterPos4xOES(x,y,z,w):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glRasterPos4xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glRectxOES(x1,y1,x2,y2):pass
@_f
@_p.types(None,arrays.GLfixedArray,arrays.GLfixedArray)
def glRectxvOES(v1,v2):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glRotatexOES(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLboolean)
def glSampleCoverageOES(value,invert):pass
@_f
@_p.types(None,_cs.GLclampx,_cs.GLboolean)
def glSampleCoveragexOES(value,invert):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glScalexOES(x,y,z):pass
@_f
@_p.types(None,_cs.GLfixed)
def glTexCoord1xOES(s):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glTexCoord1xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glTexCoord2xOES(s,t):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glTexCoord2xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glTexCoord3xOES(s,t,r):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glTexCoord3xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glTexCoord4xOES(s,t,r,q):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glTexCoord4xvOES(coords):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glTexEnvxOES(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glTexEnvxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glTexGenxOES(coord,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glTexGenxvOES(coord,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glTexParameterxOES(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glTexParameterxvOES(target,pname,params):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glTranslatexOES(x,y,z):pass
@_f
@_p.types(None,_cs.GLfixed)
def glVertex2xOES(x):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glVertex2xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glVertex3xOES(x,y):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glVertex3xvOES(coords):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glVertex4xOES(x,y,z):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glVertex4xvOES(coords):pass



'''OpenGL extension S3.s3tc

This module customises the behaviour of the 
OpenGL.raw.GL.S3.s3tc to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows specifying texture data in compressed S3TC
	format.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/S3/s3tc.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.S3.s3tc import *
from OpenGL.raw.GL.S3.s3tc import _EXTENSION_NAME

def glInitS3TcS3():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_internalformat_sample_query'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_internalformat_sample_query',error_checker=_errors._error_checker)
GL_CONFORMANT_NV=_C('GL_CONFORMANT_NV',0x9374)
GL_MULTISAMPLES_NV=_C('GL_MULTISAMPLES_NV',0x9371)
GL_RENDERBUFFER=_C('GL_RENDERBUFFER',0x8D41)
GL_SUPERSAMPLE_SCALE_X_NV=_C('GL_SUPERSAMPLE_SCALE_X_NV',0x9372)
GL_SUPERSAMPLE_SCALE_Y_NV=_C('GL_SUPERSAMPLE_SCALE_Y_NV',0x9373)
GL_TEXTURE_2D_MULTISAMPLE=_C('GL_TEXTURE_2D_MULTISAMPLE',0x9100)
GL_TEXTURE_2D_MULTISAMPLE_ARRAY=_C('GL_TEXTURE_2D_MULTISAMPLE_ARRAY',0x9102)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,arrays.GLintArray)
def glGetInternalformatSampleivNV(target,internalformat,samples,pname,bufSize,params):pass



"""Helper functions for wrapping array-using operations

These are functions intended to be used in wrapping
GL functions that deal with OpenGL array data-types.
"""
import OpenGL
import ctypes
from OpenGL import _configflags
from OpenGL import contextdata, error, converters
from OpenGL.arrays import arraydatatype
from OpenGL._bytes import bytes,unicode
import logging
_log = logging.getLogger( 'OpenGL.arrays.arrayhelpers' )
from OpenGL import acceleratesupport
AsArrayTypedSizeChecked = None
if acceleratesupport.ACCELERATE_AVAILABLE:
    try:
        from OpenGL_accelerate.arraydatatype import AsArrayTypedSizeChecked
        from OpenGL_accelerate.wrapper import returnPyArgumentIndex
        from OpenGL_accelerate.arraydatatype import (
            AsArrayOfType,AsArrayTyped,AsArrayTypedSize
        )
    except ImportError as err:
        _log.warning(
            "Unable to load arrayhelpers accelerator from OpenGL_accelerate"
        )
if AsArrayTypedSizeChecked is None:
    def returnPointer( result,baseOperation,pyArgs,cArgs, ):
        """Return the converted object as result of function
        
        Note: this is a hack that always returns pyArgs[0]!
        """
        return pyArgs[0]
    class AsArrayOfType( converters.PyConverter ):
        """Given arrayName and typeName coerce arrayName to array of type typeName
        
        TODO: It should be possible to drop this if ERROR_ON_COPY,
        as array inputs always have to be the final objects in that 
        case.
        """
        argNames = ( 'arrayName','typeName' )
        indexLookups = ( 
            ('arrayIndex', 'arrayName','pyArgIndex'),
            ('typeIndex', 'typeName','pyArgIndex'),
        )
        def __init__( self, arrayName='pointer', typeName='type' ):
            self.arrayName = arrayName
            self.typeName = typeName 
        def __call__( self, arg, wrappedOperation, args):
            """Get the arg as an array of the appropriate type"""
            type = args[ self.typeIndex ]
            arrayType = arraydatatype.GL_CONSTANT_TO_ARRAY_TYPE[ type ]
            return arrayType.asArray( arg )
    class AsArrayTyped( converters.PyConverter ):
        """Given arrayName and arrayType, convert arrayName to array of type
        
        TODO: It should be possible to drop this if ERROR_ON_COPY,
        as array inputs always have to be the final objects in that 
        case.
        """
        argNames = ( 'arrayName','arrayType' )
        indexLookups = ( 
            ('arrayIndex', 'arrayName','pyArgIndex'),
        )
        def __init__( self, arrayName='pointer', arrayType=None ):
            self.arrayName = arrayName
            self.arrayType = arrayType
        def __call__( self, arg, wrappedOperation, args):
            """Get the arg as an array of the appropriate type"""
            return self.arrayType.asArray( arg )
    class AsArrayTypedSize( converters.CConverter ):
        """Given arrayName and arrayType, determine size of arrayName
        """
        argNames = ( 'arrayName','arrayType' )
        indexLookups = ( 
            ('arrayIndex', 'arrayName','pyArgIndex'),
        )
        def __init__( self, arrayName='pointer', arrayType=None ):
            self.arrayName = arrayName
            self.arrayType = arrayType
        def __call__( self, pyArgs, index, wrappedOperation ):
            """Get the arg as an array of the appropriate type"""
            return self.arrayType.arraySize( pyArgs[self.arrayIndex ] )
else:
    returnPointer = returnPyArgumentIndex( 0 )

if not _configflags.ERROR_ON_COPY:
    def asArrayType( typ, size=None ):
        """Create PyConverter to get first argument as array of type"""
        return converters.CallFuncPyConverter( typ.asArray )
else:
    def asArrayType( typ, size=None ):
        """No converter required"""
        return None

if not _configflags.ARRAY_SIZE_CHECKING:
    asArrayTypeSize = asArrayType
else:
    if AsArrayTypedSizeChecked:
        asArrayTypeSize = AsArrayTypedSizeChecked
    else:
        def asArrayTypeSize( typ, size ):
            """Create PyConverter function to get array as type and check size
            
            Produces a raw function, not a PyConverter instance
            """
            asArray = typ.asArray
            dataType = typ.typeConstant
            arraySize = typ.arraySize
            expectedBytes = ctypes.sizeof( typ.baseType ) * size
            def asArraySize( incoming, function, args ):
                handler = typ.getHandler( incoming )
                result = handler.asArray( incoming, dataType )
                # check that the number of bytes expected is present...
                byteSize = handler.arrayByteCount( result )
                if byteSize != expectedBytes:
                    raise ValueError(
                        """Expected %r byte array, got %r byte array"""%(
                            expectedBytes,
                            byteSize,
                        ),
                        incoming,
                    )
                return result
            return asArraySize


if not _configflags.ERROR_ON_COPY:
    def asVoidArray( ):
        """Create PyConverter returning incoming as an array of any type"""
        from OpenGL.arrays import ArrayDatatype
        return converters.CallFuncPyConverter( ArrayDatatype.asArray )
else:
    def asVoidArray( ):
        """If there's no copying allowed, we can use default passing"""
        return None

class storePointerType( object ):
    """Store named pointer value in context indexed by constant
    
    pointerName -- named pointer argument 
    constant -- constant used to index in the context storage
    
    Note: OpenGL.STORE_POINTERS can be set with ERROR_ON_COPY
    to ignore this storage operation.
    
    Stores the pyArgs (i.e. result of pyConverters) for the named
    pointer argument...
    """
    def __init__( self, pointerName, constant ):
        self.pointerName = pointerName
        self.constant = constant 
    def finalise( self, wrapper ):
        self.pointerIndex = wrapper.pyArgIndex( self.pointerName )
    def __call__( self, result, baseOperation, pyArgs, cArgs ):
        contextdata.setValue( self.constant, pyArgs[self.pointerIndex] )


def setInputArraySizeType( baseOperation, size, type, argName=0 ):
    """Decorate function with vector-handling code for a single argument
    
    if OpenGL.ERROR_ON_COPY is False, then we return the 
    named argument, converting to the passed array type,
    optionally checking that the array matches size.
    
    if OpenGL.ERROR_ON_COPY is True, then we will dramatically 
    simplify this function, only wrapping if size is True, i.e.
    only wrapping if we intend to do a size check on the array.
    """
    from OpenGL import wrapper
    return wrapper.wrapper( baseOperation ).setInputArraySize( argName, size )

def arraySizeOfFirstType( typ, default ):
    unitSize = typ.unitSize
    def arraySizeOfFirst( pyArgs, index, baseOperation ):
        """Return the array size of the first argument"""
        array = pyArgs[0]
        if array is None:
            return default
        else:
            return unitSize( array )
    return arraySizeOfFirst



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_ARB_pixel_format_float'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_ARB_pixel_format_float',error_checker=_errors._error_checker)
WGL_TYPE_RGBA_FLOAT_ARB=_C('WGL_TYPE_RGBA_FLOAT_ARB',0x21A0)




'''OpenGL extension NV.vertex_program2_option

This module customises the behaviour of the 
OpenGL.raw.GL.NV.vertex_program2_option to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides additional vertex program functionality
	to extend the standard ARB_vertex_program language and execution
	environment.  ARB programs wishing to use this added functionality
	need only add:
	
	    OPTION NV_vertex_program2;
	
	to the beginning of their vertex programs.
	
	The functionality provided by this extension, which is roughly
	equivalent to that provided by the NV_vertex_program2 extension,
	includes:
	
	  * general purpose dynamic branching,
	
	  * subroutine calls,
	
	  * data-dependent conditional write masks,
	
	  * programmable user clip distances,
	
	  * address registers with four components (instead of just one),
	
	  * absolute value operator on scalar and swizzled operand loads,
	
	  * rudimentary address register math,
	
	  * SIN and COS trigonometry instructions, and
	
	  * fully orthogonal "set on" instructions, including a "set sign"
	    instruction.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_program2_option.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.vertex_program2_option import *
from OpenGL.raw.GL.NV.vertex_program2_option import _EXTENSION_NAME

def glInitVertexProgram2OptionNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.video_capture

This module customises the behaviour of the 
OpenGL.raw.GLX.NV.video_capture to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a mechanism for streaming video data
	directly into texture objects and buffer objects.  Applications can
	then display video streams in interactive 3D scenes and/or
	manipulate the video data using the GL's image processing
	capabilities.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/video_capture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.NV.video_capture import *
from OpenGL.raw.GLX.NV.video_capture import _EXTENSION_NAME

def glInitVideoCaptureNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_I3D_swap_frame_usage'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_I3D_swap_frame_usage',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.BOOL,)
def wglBeginFrameTrackingI3D():pass
@_f
@_p.types(_cs.BOOL,)
def wglEndFrameTrackingI3D():pass
@_f
@_p.types(_cs.BOOL,arrays.GLfloatArray)
def wglGetFrameUsageI3D(pUsage):pass
@_f
@_p.types(_cs.BOOL,ctypes.POINTER(_cs.DWORD),ctypes.POINTER(_cs.DWORD),arrays.GLfloatArray)
def wglQueryFrameTrackingI3D(pFrameCount,pMissedFrames,pLastMissedUsage):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_vertex_shader'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_vertex_shader',error_checker=_errors._error_checker)
GL_CURRENT_VERTEX_ATTRIB_ARB=_C('GL_CURRENT_VERTEX_ATTRIB_ARB',0x8626)
GL_FLOAT=_C('GL_FLOAT',0x1406)
GL_FLOAT_MAT2_ARB=_C('GL_FLOAT_MAT2_ARB',0x8B5A)
GL_FLOAT_MAT3_ARB=_C('GL_FLOAT_MAT3_ARB',0x8B5B)
GL_FLOAT_MAT4_ARB=_C('GL_FLOAT_MAT4_ARB',0x8B5C)
GL_FLOAT_VEC2_ARB=_C('GL_FLOAT_VEC2_ARB',0x8B50)
GL_FLOAT_VEC3_ARB=_C('GL_FLOAT_VEC3_ARB',0x8B51)
GL_FLOAT_VEC4_ARB=_C('GL_FLOAT_VEC4_ARB',0x8B52)
GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB=_C('GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB',0x8B4D)
GL_MAX_TEXTURE_COORDS_ARB=_C('GL_MAX_TEXTURE_COORDS_ARB',0x8871)
GL_MAX_TEXTURE_IMAGE_UNITS_ARB=_C('GL_MAX_TEXTURE_IMAGE_UNITS_ARB',0x8872)
GL_MAX_VARYING_FLOATS_ARB=_C('GL_MAX_VARYING_FLOATS_ARB',0x8B4B)
GL_MAX_VERTEX_ATTRIBS_ARB=_C('GL_MAX_VERTEX_ATTRIBS_ARB',0x8869)
GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB=_C('GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB',0x8B4C)
GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB=_C('GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB',0x8B4A)
GL_OBJECT_ACTIVE_ATTRIBUTES_ARB=_C('GL_OBJECT_ACTIVE_ATTRIBUTES_ARB',0x8B89)
GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB=_C('GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB',0x8B8A)
GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB',0x8622)
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB',0x886A)
GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB',0x8645)
GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB',0x8623)
GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB',0x8624)
GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB=_C('GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB',0x8625)
GL_VERTEX_PROGRAM_POINT_SIZE_ARB=_C('GL_VERTEX_PROGRAM_POINT_SIZE_ARB',0x8642)
GL_VERTEX_PROGRAM_TWO_SIDE_ARB=_C('GL_VERTEX_PROGRAM_TWO_SIDE_ARB',0x8643)
GL_VERTEX_SHADER_ARB=_C('GL_VERTEX_SHADER_ARB',0x8B31)
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLuint,arrays.GLcharARBArray)
def glBindAttribLocationARB(programObj,index,name):pass
@_f
@_p.types(None,_cs.GLuint)
def glDisableVertexAttribArrayARB(index):pass
@_f
@_p.types(None,_cs.GLuint)
def glEnableVertexAttribArrayARB(index):pass
@_f
@_p.types(None,_cs.GLhandleARB,_cs.GLuint,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray,arrays.GLuintArray,arrays.GLcharARBArray)
def glGetActiveAttribARB(programObj,index,maxLength,length,size,type,name):pass
@_f
@_p.types(_cs.GLint,_cs.GLhandleARB,arrays.GLcharARBArray)
def glGetAttribLocationARB(programObj,name):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLvoidpArray)
def glGetVertexAttribPointervARB(index,pname,pointer):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLdoubleArray)
def glGetVertexAttribdvARB(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLfloatArray)
def glGetVertexAttribfvARB(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetVertexAttribivARB(index,pname,params):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble)
def glVertexAttrib1dARB(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib1dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat)
def glVertexAttrib1fARB(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib1fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort)
def glVertexAttrib1sARB(index,x):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib1svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib2dARB(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib2dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib2fARB(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib2fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort)
def glVertexAttrib2sARB(index,x,y):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib2svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib3dARB(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib3dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib3fARB(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib3fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertexAttrib3sARB(index,x,y,z):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib3svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVertexAttrib4NbvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttrib4NivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib4NsvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glVertexAttrib4NubARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttrib4NubvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttrib4NuivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib4NusvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLbyteArray)
def glVertexAttrib4bvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glVertexAttrib4dARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLdoubleArray)
def glVertexAttrib4dvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glVertexAttrib4fARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLfloatArray)
def glVertexAttrib4fvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLintArray)
def glVertexAttrib4ivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glVertexAttrib4sARB(index,x,y,z,w):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLshortArray)
def glVertexAttrib4svARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLubyteArray)
def glVertexAttrib4ubvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLuintArray)
def glVertexAttrib4uivARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,arrays.GLushortArray)
def glVertexAttrib4usvARB(index,v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLint,_cs.GLenum,_cs.GLboolean,_cs.GLsizei,ctypes.c_void_p)
def glVertexAttribPointerARB(index,size,type,normalized,stride,pointer):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_render_snorm'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_render_snorm',error_checker=_errors._error_checker)
GL_BYTE=_C('GL_BYTE',0x1400)
GL_R16_SNORM_EXT=_C('GL_R16_SNORM_EXT',0x8F98)
GL_R8_SNORM=_C('GL_R8_SNORM',0x8F94)
GL_RG16_SNORM_EXT=_C('GL_RG16_SNORM_EXT',0x8F99)
GL_RG8_SNORM=_C('GL_RG8_SNORM',0x8F95)
GL_RGBA16_SNORM_EXT=_C('GL_RGBA16_SNORM_EXT',0x8F9B)
GL_RGBA8_SNORM=_C('GL_RGBA8_SNORM',0x8F97)
GL_SHORT=_C('GL_SHORT',0x1402)




'''OpenGL extension SGIX.texture_multi_buffer

This module customises the behaviour of the 
OpenGL.raw.GL.SGIX.texture_multi_buffer to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides an API for the application to specify that
	the OpenGL should handle multiple textures in such a way that,
	wherever possible, a texture definition or redefinition can occur
	in parallel with rendering that uses a different texture.
	
	The texture_object extension allows the simultaneous definition
	of multiple textures; any texture that is not being used for 
	rendering can, in principle, have its definition or operations
	in its definition (e.g. downloading to hardware) occur in parallel
	with the use of another texture. This is true as long as all
	redefinitions strictly follow any use of the previous definition.
	
	Conceptually this is similar to frame buffer double-buffering,
	except that the intent here is to simply provide a hint to the
	OpenGL to promote such double-buffering if and wherever possible.
	The effect of such a hint is to speed up operations without
	affecting the result. The user on any particular system must be
	knowledgable and prepared to accept any trade-offs which follow
	from such a hint.
	
	GL_FASTEST in this context means that texture multi-buffering
	is being used whenever possible to improve performance. 
	Generally, textures that are adjacent in a sequence of multiple
	texture definitions have the greatest chance of being in 
	different buffers. The number of buffers available at any time
	depends on various factors, such as the machine being used and
	the textures' internal formats.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/SGIX/texture_multi_buffer.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.SGIX.texture_multi_buffer import *
from OpenGL.raw.GL.SGIX.texture_multi_buffer import _EXTENSION_NAME

def glInitTextureMultiBufferSGIX():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_multi_bind'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_multi_bind',error_checker=_errors._error_checker)

@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindBuffersBase(target,first,count,buffers):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,ctypes.POINTER(_cs.GLintptr),ctypes.POINTER(_cs.GLsizeiptr))
def glBindBuffersRange(target,first,count,buffers,offsets,sizes):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindImageTextures(first,count,textures):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindSamplers(first,count,samplers):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray)
def glBindTextures(first,count,textures):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLsizei,arrays.GLuintArray,ctypes.POINTER(_cs.GLintptr),arrays.GLsizeiArray)
def glBindVertexBuffers(first,count,buffers,offsets,strides):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_vdpau_interop'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_vdpau_interop',error_checker=_errors._error_checker)
GL_SURFACE_MAPPED_NV=_C('GL_SURFACE_MAPPED_NV',0x8700)
GL_SURFACE_REGISTERED_NV=_C('GL_SURFACE_REGISTERED_NV',0x86FD)
GL_SURFACE_STATE_NV=_C('GL_SURFACE_STATE_NV',0x86EB)
GL_WRITE_DISCARD_NV=_C('GL_WRITE_DISCARD_NV',0x88BE)
@_f
@_p.types(None,)
def glVDPAUFiniNV():pass
@_f
@_p.types(None,_cs.GLvdpauSurfaceNV,_cs.GLenum,_cs.GLsizei,arrays.GLsizeiArray,arrays.GLintArray)
def glVDPAUGetSurfaceivNV(surface,pname,bufSize,length,values):pass
@_f
@_p.types(None,ctypes.c_void_p,ctypes.c_void_p)
def glVDPAUInitNV(vdpDevice,getProcAddress):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLvdpauSurfaceNV)
def glVDPAUIsSurfaceNV(surface):pass
@_f
@_p.types(None,_cs.GLsizei,ctypes.POINTER(_cs.GLvdpauSurfaceNV))
def glVDPAUMapSurfacesNV(numSurfaces,surfaces):pass
@_f
@_p.types(_cs.GLvdpauSurfaceNV,ctypes.c_void_p,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glVDPAURegisterOutputSurfaceNV(vdpSurface,target,numTextureNames,textureNames):pass
@_f
@_p.types(_cs.GLvdpauSurfaceNV,ctypes.c_void_p,_cs.GLenum,_cs.GLsizei,arrays.GLuintArray)
def glVDPAURegisterVideoSurfaceNV(vdpSurface,target,numTextureNames,textureNames):pass
@_f
@_p.types(None,_cs.GLvdpauSurfaceNV,_cs.GLenum)
def glVDPAUSurfaceAccessNV(surface,access):pass
@_f
@_p.types(None,_cs.GLsizei,ctypes.POINTER(_cs.GLvdpauSurfaceNV))
def glVDPAUUnmapSurfacesNV(numSurface,surfaces):pass
@_f
@_p.types(None,_cs.GLvdpauSurfaceNV)
def glVDPAUUnregisterSurfaceNV(surface):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_convolution'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_convolution',error_checker=_errors._error_checker)
GL_CONVOLUTION_1D_EXT=_C('GL_CONVOLUTION_1D_EXT',0x8010)
GL_CONVOLUTION_2D_EXT=_C('GL_CONVOLUTION_2D_EXT',0x8011)
GL_CONVOLUTION_BORDER_MODE_EXT=_C('GL_CONVOLUTION_BORDER_MODE_EXT',0x8013)
GL_CONVOLUTION_FILTER_BIAS_EXT=_C('GL_CONVOLUTION_FILTER_BIAS_EXT',0x8015)
GL_CONVOLUTION_FILTER_SCALE_EXT=_C('GL_CONVOLUTION_FILTER_SCALE_EXT',0x8014)
GL_CONVOLUTION_FORMAT_EXT=_C('GL_CONVOLUTION_FORMAT_EXT',0x8017)
GL_CONVOLUTION_HEIGHT_EXT=_C('GL_CONVOLUTION_HEIGHT_EXT',0x8019)
GL_CONVOLUTION_WIDTH_EXT=_C('GL_CONVOLUTION_WIDTH_EXT',0x8018)
GL_MAX_CONVOLUTION_HEIGHT_EXT=_C('GL_MAX_CONVOLUTION_HEIGHT_EXT',0x801B)
GL_MAX_CONVOLUTION_WIDTH_EXT=_C('GL_MAX_CONVOLUTION_WIDTH_EXT',0x801A)
GL_POST_CONVOLUTION_ALPHA_BIAS_EXT=_C('GL_POST_CONVOLUTION_ALPHA_BIAS_EXT',0x8023)
GL_POST_CONVOLUTION_ALPHA_SCALE_EXT=_C('GL_POST_CONVOLUTION_ALPHA_SCALE_EXT',0x801F)
GL_POST_CONVOLUTION_BLUE_BIAS_EXT=_C('GL_POST_CONVOLUTION_BLUE_BIAS_EXT',0x8022)
GL_POST_CONVOLUTION_BLUE_SCALE_EXT=_C('GL_POST_CONVOLUTION_BLUE_SCALE_EXT',0x801E)
GL_POST_CONVOLUTION_GREEN_BIAS_EXT=_C('GL_POST_CONVOLUTION_GREEN_BIAS_EXT',0x8021)
GL_POST_CONVOLUTION_GREEN_SCALE_EXT=_C('GL_POST_CONVOLUTION_GREEN_SCALE_EXT',0x801D)
GL_POST_CONVOLUTION_RED_BIAS_EXT=_C('GL_POST_CONVOLUTION_RED_BIAS_EXT',0x8020)
GL_POST_CONVOLUTION_RED_SCALE_EXT=_C('GL_POST_CONVOLUTION_RED_SCALE_EXT',0x801C)
GL_REDUCE_EXT=_C('GL_REDUCE_EXT',0x8016)
GL_SEPARABLE_2D_EXT=_C('GL_SEPARABLE_2D_EXT',0x8012)
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glConvolutionFilter1DEXT(target,internalformat,width,format,type,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glConvolutionFilter2DEXT(target,internalformat,width,height,format,type,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glConvolutionParameterfEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glConvolutionParameterfvEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glConvolutionParameteriEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glConvolutionParameterivEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei)
def glCopyConvolutionFilter1DEXT(target,internalformat,x,y,width):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyConvolutionFilter2DEXT(target,internalformat,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glGetConvolutionFilterEXT(target,format,type,image):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetConvolutionParameterfvEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetConvolutionParameterivEXT(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,ctypes.c_void_p,ctypes.c_void_p,ctypes.c_void_p)
def glGetSeparableFilterEXT(target,format,type,row,column,span):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p,ctypes.c_void_p)
def glSeparableFilter2DEXT(target,internalformat,width,height,format,type,row,column):pass



'''OpenGL extension ARB.fragment_coord_conventions

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.fragment_coord_conventions to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides alternative conventions for the fragment
	coordinate XY location available for programmable fragment processing.
	
	The scope of this extension deals *only* with how the fragment
	coordinate XY location appears during programming fragment processing.
	Beyond the scope of this extension are coordinate conventions used
	for rasterization or transformation.
	
	In the case of the coordinate conventions for rasterization and
	transformation, some combination of the viewport, depth range, culling
	state, and projection matrix state can be reconfigured to adopt other
	arbitrary clip-space and window-space coordinate space conventions.
	Adopting other clip-space and window-space conventions involves
	adjusting existing OpenGL state.  However it is non-trivial to massage
	an arbitrary fragment shader or program to adopt a different
	window-space coordinate system because such shaders are encoded in
	various textual representations.
	
	The dominant 2D and 3D rendering APIs make two basic choices of
	convention when locating fragments in window space.
	
	The two choices are:
	
	1)  Is the origin nearest the lower-left- or upper-left-most pixel
	    of the window?
	
	2)  Is the (x,y) location of the pixel nearest the origin at (0,0)
	    or (0.5,0.5)?
	
	OpenGL assumes a lower-left origin for window coordinates and assumes
	pixel centers are located at half-pixel coordinates.  This means
	the XY location (0.5,0.5) corresponds to the lower-left-most pixel
	in a window.
	
	Other window coordinate conventions exist for other rendering APIs.
	X11, GDI, and Direct3D version through DirectX 9 assume an upper-left
	window origin and locate pixel centers at integer XY values.
	By this alternative convention, the XY location (0,0) corresponds
	to the upper-left-most pixel in a window.
	
	Direct3D for DirectX 10 assumes an upper-left origin (as do prior
	DirectX versions) yet assumes half-pixel coordinates (unlike prior
	DirectX versions).  By the DirectX 10 convention, the XY location
	(0.5,0.5) corresponds to the upper-left-most pixel in a window.
	
	Fragment shaders can directly access the location of a given
	processed fragment in window space.  We call this location the
	"fragment coordinate".
	
	This extension provides a means for fragment shaders written in GLSL
	or OpenGL assembly extensions to specify alternative conventions
	for determining the fragment coordinate value accessed during
	programmable fragment processing.
	
	The motivation for this extension is to provide an easy, efficient
	means for fragment shaders accessing a fragment's window-space
	location to adopt the fragment coordinate convention for which the
	shader was originally written.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/fragment_coord_conventions.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.fragment_coord_conventions import *
from OpenGL.raw.GL.ARB.fragment_coord_conventions import _EXTENSION_NAME

def glInitFragmentCoordConventionsARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


"""Constants for OpenGL.GLU

Automatically generated by the generateraw script, do not edit!
"""

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid


GLU_AUTO_LOAD_MATRIX = Constant( 'GLU_AUTO_LOAD_MATRIX', 100200)
GLU_BEGIN = Constant( 'GLU_BEGIN', 100100)
GLU_CCW = Constant( 'GLU_CCW', 100121)
GLU_CULLING = Constant( 'GLU_CULLING', 100201)
GLU_CW = Constant( 'GLU_CW', 100120)
GLU_DISPLAY_MODE = Constant( 'GLU_DISPLAY_MODE', 100204)
GLU_DOMAIN_DISTANCE = Constant( 'GLU_DOMAIN_DISTANCE', 100217)
GLU_EDGE_FLAG = Constant( 'GLU_EDGE_FLAG', 100104)
GLU_END = Constant( 'GLU_END', 100102)
GLU_ERROR = Constant( 'GLU_ERROR', 100103)
GLU_EXTENSIONS = Constant( 'GLU_EXTENSIONS', 100801)
GLU_EXTERIOR = Constant( 'GLU_EXTERIOR', 100123)
GLU_FALSE = Constant( 'GLU_FALSE', 0)
GLU_FILL = Constant( 'GLU_FILL', 100012)
GLU_FLAT = Constant( 'GLU_FLAT', 100001)
GLU_INCOMPATIBLE_GL_VERSION = Constant( 'GLU_INCOMPATIBLE_GL_VERSION', 100903)
GLU_INSIDE = Constant( 'GLU_INSIDE', 100021)
GLU_INTERIOR = Constant( 'GLU_INTERIOR', 100122)
GLU_INVALID_ENUM = Constant( 'GLU_INVALID_ENUM', 100900)
GLU_INVALID_OPERATION = Constant( 'GLU_INVALID_OPERATION', 100904)
GLU_INVALID_VALUE = Constant( 'GLU_INVALID_VALUE', 100901)
GLU_LINE = Constant( 'GLU_LINE', 100011)
GLU_MAP1_TRIM_2 = Constant( 'GLU_MAP1_TRIM_2', 100210)
GLU_MAP1_TRIM_3 = Constant( 'GLU_MAP1_TRIM_3', 100211)
GLU_NONE = Constant( 'GLU_NONE', 100002)
GLU_NURBS_BEGIN = Constant( 'GLU_NURBS_BEGIN', 100164)
GLU_NURBS_BEGIN_DATA = Constant( 'GLU_NURBS_BEGIN_DATA', 100170)
GLU_NURBS_BEGIN_DATA_EXT = Constant( 'GLU_NURBS_BEGIN_DATA_EXT', 100170)
GLU_NURBS_BEGIN_EXT = Constant( 'GLU_NURBS_BEGIN_EXT', 100164)
GLU_NURBS_COLOR = Constant( 'GLU_NURBS_COLOR', 100167)
GLU_NURBS_COLOR_DATA = Constant( 'GLU_NURBS_COLOR_DATA', 100173)
GLU_NURBS_COLOR_DATA_EXT = Constant( 'GLU_NURBS_COLOR_DATA_EXT', 100173)
GLU_NURBS_COLOR_EXT = Constant( 'GLU_NURBS_COLOR_EXT', 100167)
GLU_NURBS_END = Constant( 'GLU_NURBS_END', 100169)
GLU_NURBS_END_DATA = Constant( 'GLU_NURBS_END_DATA', 100175)
GLU_NURBS_END_DATA_EXT = Constant( 'GLU_NURBS_END_DATA_EXT', 100175)
GLU_NURBS_END_EXT = Constant( 'GLU_NURBS_END_EXT', 100169)
GLU_NURBS_ERROR = Constant( 'GLU_NURBS_ERROR', 100103)
GLU_NURBS_ERROR1 = Constant( 'GLU_NURBS_ERROR1', 100251)
GLU_NURBS_ERROR10 = Constant( 'GLU_NURBS_ERROR10', 100260)
GLU_NURBS_ERROR11 = Constant( 'GLU_NURBS_ERROR11', 100261)
GLU_NURBS_ERROR12 = Constant( 'GLU_NURBS_ERROR12', 100262)
GLU_NURBS_ERROR13 = Constant( 'GLU_NURBS_ERROR13', 100263)
GLU_NURBS_ERROR14 = Constant( 'GLU_NURBS_ERROR14', 100264)
GLU_NURBS_ERROR15 = Constant( 'GLU_NURBS_ERROR15', 100265)
GLU_NURBS_ERROR16 = Constant( 'GLU_NURBS_ERROR16', 100266)
GLU_NURBS_ERROR17 = Constant( 'GLU_NURBS_ERROR17', 100267)
GLU_NURBS_ERROR18 = Constant( 'GLU_NURBS_ERROR18', 100268)
GLU_NURBS_ERROR19 = Constant( 'GLU_NURBS_ERROR19', 100269)
GLU_NURBS_ERROR2 = Constant( 'GLU_NURBS_ERROR2', 100252)
GLU_NURBS_ERROR20 = Constant( 'GLU_NURBS_ERROR20', 100270)
GLU_NURBS_ERROR21 = Constant( 'GLU_NURBS_ERROR21', 100271)
GLU_NURBS_ERROR22 = Constant( 'GLU_NURBS_ERROR22', 100272)
GLU_NURBS_ERROR23 = Constant( 'GLU_NURBS_ERROR23', 100273)
GLU_NURBS_ERROR24 = Constant( 'GLU_NURBS_ERROR24', 100274)
GLU_NURBS_ERROR25 = Constant( 'GLU_NURBS_ERROR25', 100275)
GLU_NURBS_ERROR26 = Constant( 'GLU_NURBS_ERROR26', 100276)
GLU_NURBS_ERROR27 = Constant( 'GLU_NURBS_ERROR27', 100277)
GLU_NURBS_ERROR28 = Constant( 'GLU_NURBS_ERROR28', 100278)
GLU_NURBS_ERROR29 = Constant( 'GLU_NURBS_ERROR29', 100279)
GLU_NURBS_ERROR3 = Constant( 'GLU_NURBS_ERROR3', 100253)
GLU_NURBS_ERROR30 = Constant( 'GLU_NURBS_ERROR30', 100280)
GLU_NURBS_ERROR31 = Constant( 'GLU_NURBS_ERROR31', 100281)
GLU_NURBS_ERROR32 = Constant( 'GLU_NURBS_ERROR32', 100282)
GLU_NURBS_ERROR33 = Constant( 'GLU_NURBS_ERROR33', 100283)
GLU_NURBS_ERROR34 = Constant( 'GLU_NURBS_ERROR34', 100284)
GLU_NURBS_ERROR35 = Constant( 'GLU_NURBS_ERROR35', 100285)
GLU_NURBS_ERROR36 = Constant( 'GLU_NURBS_ERROR36', 100286)
GLU_NURBS_ERROR37 = Constant( 'GLU_NURBS_ERROR37', 100287)
GLU_NURBS_ERROR4 = Constant( 'GLU_NURBS_ERROR4', 100254)
GLU_NURBS_ERROR5 = Constant( 'GLU_NURBS_ERROR5', 100255)
GLU_NURBS_ERROR6 = Constant( 'GLU_NURBS_ERROR6', 100256)
GLU_NURBS_ERROR7 = Constant( 'GLU_NURBS_ERROR7', 100257)
GLU_NURBS_ERROR8 = Constant( 'GLU_NURBS_ERROR8', 100258)
GLU_NURBS_ERROR9 = Constant( 'GLU_NURBS_ERROR9', 100259)
GLU_NURBS_MODE = Constant( 'GLU_NURBS_MODE', 100160)
GLU_NURBS_MODE_EXT = Constant( 'GLU_NURBS_MODE_EXT', 100160)
GLU_NURBS_NORMAL = Constant( 'GLU_NURBS_NORMAL', 100166)
GLU_NURBS_NORMAL_DATA = Constant( 'GLU_NURBS_NORMAL_DATA', 100172)
GLU_NURBS_NORMAL_DATA_EXT = Constant( 'GLU_NURBS_NORMAL_DATA_EXT', 100172)
GLU_NURBS_NORMAL_EXT = Constant( 'GLU_NURBS_NORMAL_EXT', 100166)
GLU_NURBS_RENDERER = Constant( 'GLU_NURBS_RENDERER', 100162)
GLU_NURBS_RENDERER_EXT = Constant( 'GLU_NURBS_RENDERER_EXT', 100162)
GLU_NURBS_TESSELLATOR = Constant( 'GLU_NURBS_TESSELLATOR', 100161)
GLU_NURBS_TESSELLATOR_EXT = Constant( 'GLU_NURBS_TESSELLATOR_EXT', 100161)
GLU_NURBS_TEXTURE_COORD = Constant( 'GLU_NURBS_TEXTURE_COORD', 100168)
GLU_NURBS_TEXTURE_COORD_DATA = Constant( 'GLU_NURBS_TEXTURE_COORD_DATA', 100174)
GLU_NURBS_TEX_COORD_DATA_EXT = Constant( 'GLU_NURBS_TEX_COORD_DATA_EXT', 100174)
GLU_NURBS_TEX_COORD_EXT = Constant( 'GLU_NURBS_TEX_COORD_EXT', 100168)
GLU_NURBS_VERTEX = Constant( 'GLU_NURBS_VERTEX', 100165)
GLU_NURBS_VERTEX_DATA = Constant( 'GLU_NURBS_VERTEX_DATA', 100171)
GLU_NURBS_VERTEX_DATA_EXT = Constant( 'GLU_NURBS_VERTEX_DATA_EXT', 100171)
GLU_NURBS_VERTEX_EXT = Constant( 'GLU_NURBS_VERTEX_EXT', 100165)
GLU_OBJECT_PARAMETRIC_ERROR = Constant( 'GLU_OBJECT_PARAMETRIC_ERROR', 100208)
GLU_OBJECT_PARAMETRIC_ERROR_EXT = Constant( 'GLU_OBJECT_PARAMETRIC_ERROR_EXT', 100208)
GLU_OBJECT_PATH_LENGTH = Constant( 'GLU_OBJECT_PATH_LENGTH', 100209)
GLU_OBJECT_PATH_LENGTH_EXT = Constant( 'GLU_OBJECT_PATH_LENGTH_EXT', 100209)
GLU_OUTLINE_PATCH = Constant( 'GLU_OUTLINE_PATCH', 100241)
GLU_OUTLINE_POLYGON = Constant( 'GLU_OUTLINE_POLYGON', 100240)
GLU_OUTSIDE = Constant( 'GLU_OUTSIDE', 100020)
GLU_OUT_OF_MEMORY = Constant( 'GLU_OUT_OF_MEMORY', 100902)
GLU_PARAMETRIC_ERROR = Constant( 'GLU_PARAMETRIC_ERROR', 100216)
GLU_PARAMETRIC_TOLERANCE = Constant( 'GLU_PARAMETRIC_TOLERANCE', 100202)
GLU_PATH_LENGTH = Constant( 'GLU_PATH_LENGTH', 100215)
GLU_POINT = Constant( 'GLU_POINT', 100010)
GLU_SAMPLING_METHOD = Constant( 'GLU_SAMPLING_METHOD', 100205)
GLU_SAMPLING_TOLERANCE = Constant( 'GLU_SAMPLING_TOLERANCE', 100203)
GLU_SILHOUETTE = Constant( 'GLU_SILHOUETTE', 100013)
GLU_SMOOTH = Constant( 'GLU_SMOOTH', 100000)
GLU_TESS_BEGIN = Constant( 'GLU_TESS_BEGIN', 100100)
GLU_TESS_BEGIN_DATA = Constant( 'GLU_TESS_BEGIN_DATA', 100106)
GLU_TESS_BOUNDARY_ONLY = Constant( 'GLU_TESS_BOUNDARY_ONLY', 100141)
GLU_TESS_COMBINE = Constant( 'GLU_TESS_COMBINE', 100105)
GLU_TESS_COMBINE_DATA = Constant( 'GLU_TESS_COMBINE_DATA', 100111)
GLU_TESS_COORD_TOO_LARGE = Constant( 'GLU_TESS_COORD_TOO_LARGE', 100155)
GLU_TESS_EDGE_FLAG = Constant( 'GLU_TESS_EDGE_FLAG', 100104)
GLU_TESS_EDGE_FLAG_DATA = Constant( 'GLU_TESS_EDGE_FLAG_DATA', 100110)
GLU_TESS_END = Constant( 'GLU_TESS_END', 100102)
GLU_TESS_END_DATA = Constant( 'GLU_TESS_END_DATA', 100108)
GLU_TESS_ERROR = Constant( 'GLU_TESS_ERROR', 100103)
GLU_TESS_ERROR1 = Constant( 'GLU_TESS_ERROR1', 100151)
GLU_TESS_ERROR2 = Constant( 'GLU_TESS_ERROR2', 100152)
GLU_TESS_ERROR3 = Constant( 'GLU_TESS_ERROR3', 100153)
GLU_TESS_ERROR4 = Constant( 'GLU_TESS_ERROR4', 100154)
GLU_TESS_ERROR5 = Constant( 'GLU_TESS_ERROR5', 100155)
GLU_TESS_ERROR6 = Constant( 'GLU_TESS_ERROR6', 100156)
GLU_TESS_ERROR7 = Constant( 'GLU_TESS_ERROR7', 100157)
GLU_TESS_ERROR8 = Constant( 'GLU_TESS_ERROR8', 100158)
GLU_TESS_ERROR_DATA = Constant( 'GLU_TESS_ERROR_DATA', 100109)
GLU_TESS_MAX_COORD = Constant( 'GLU_TESS_MAX_COORD', 9.9999999999999998e+149)
GLU_TESS_MISSING_BEGIN_CONTOUR = Constant( 'GLU_TESS_MISSING_BEGIN_CONTOUR', 100152)
GLU_TESS_MISSING_BEGIN_POLYGON = Constant( 'GLU_TESS_MISSING_BEGIN_POLYGON', 100151)
GLU_TESS_MISSING_END_CONTOUR = Constant( 'GLU_TESS_MISSING_END_CONTOUR', 100154)
GLU_TESS_MISSING_END_POLYGON = Constant( 'GLU_TESS_MISSING_END_POLYGON', 100153)
GLU_TESS_NEED_COMBINE_CALLBACK = Constant( 'GLU_TESS_NEED_COMBINE_CALLBACK', 100156)
GLU_TESS_TOLERANCE = Constant( 'GLU_TESS_TOLERANCE', 100142)
GLU_TESS_VERTEX = Constant( 'GLU_TESS_VERTEX', 100101)
GLU_TESS_VERTEX_DATA = Constant( 'GLU_TESS_VERTEX_DATA', 100107)
GLU_TESS_WINDING_ABS_GEQ_TWO = Constant( 'GLU_TESS_WINDING_ABS_GEQ_TWO', 100134)
GLU_TESS_WINDING_NEGATIVE = Constant( 'GLU_TESS_WINDING_NEGATIVE', 100133)
GLU_TESS_WINDING_NONZERO = Constant( 'GLU_TESS_WINDING_NONZERO', 100131)
GLU_TESS_WINDING_ODD = Constant( 'GLU_TESS_WINDING_ODD', 100130)
GLU_TESS_WINDING_POSITIVE = Constant( 'GLU_TESS_WINDING_POSITIVE', 100132)
GLU_TESS_WINDING_RULE = Constant( 'GLU_TESS_WINDING_RULE', 100140)
GLU_TRUE = Constant( 'GLU_TRUE', 1)
GLU_UNKNOWN = Constant( 'GLU_UNKNOWN', 100124)
GLU_U_STEP = Constant( 'GLU_U_STEP', 100206)
GLU_VERSION = Constant( 'GLU_VERSION', 100800)
GLU_VERSION_1_1 = Constant( 'GLU_VERSION_1_1', 1)
GLU_VERSION_1_2 = Constant( 'GLU_VERSION_1_2', 1)
GLU_VERSION_1_3 = Constant( 'GLU_VERSION_1_3', 1)
GLU_VERTEX = Constant( 'GLU_VERTEX', 100101)
GLU_V_STEP = Constant( 'GLU_V_STEP', 100207)
__all__ = [
    'GLU_AUTO_LOAD_MATRIX',
    'GLU_BEGIN',
    'GLU_CCW',
    'GLU_CULLING',
    'GLU_CW',
    'GLU_DISPLAY_MODE',
    'GLU_DOMAIN_DISTANCE',
    'GLU_EDGE_FLAG',
    'GLU_END',
    'GLU_ERROR',
    'GLU_EXTENSIONS',
    'GLU_EXTERIOR',
    'GLU_FALSE',
    'GLU_FILL',
    'GLU_FLAT',
    'GLU_INCOMPATIBLE_GL_VERSION',
    'GLU_INSIDE',
    'GLU_INTERIOR',
    'GLU_INVALID_ENUM',
    'GLU_INVALID_OPERATION',
    'GLU_INVALID_VALUE',
    'GLU_LINE',
    'GLU_MAP1_TRIM_2',
    'GLU_MAP1_TRIM_3',
    'GLU_NONE',
    'GLU_NURBS_BEGIN',
    'GLU_NURBS_BEGIN_DATA',
    'GLU_NURBS_BEGIN_DATA_EXT',
    'GLU_NURBS_BEGIN_EXT',
    'GLU_NURBS_COLOR',
    'GLU_NURBS_COLOR_DATA',
    'GLU_NURBS_COLOR_DATA_EXT',
    'GLU_NURBS_COLOR_EXT',
    'GLU_NURBS_END',
    'GLU_NURBS_END_DATA',
    'GLU_NURBS_END_DATA_EXT',
    'GLU_NURBS_END_EXT',
    'GLU_NURBS_ERROR',
    'GLU_NURBS_ERROR1',
    'GLU_NURBS_ERROR10',
    'GLU_NURBS_ERROR11',
    'GLU_NURBS_ERROR12',
    'GLU_NURBS_ERROR13',
    'GLU_NURBS_ERROR14',
    'GLU_NURBS_ERROR15',
    'GLU_NURBS_ERROR16',
    'GLU_NURBS_ERROR17',
    'GLU_NURBS_ERROR18',
    'GLU_NURBS_ERROR19',
    'GLU_NURBS_ERROR2',
    'GLU_NURBS_ERROR20',
    'GLU_NURBS_ERROR21',
    'GLU_NURBS_ERROR22',
    'GLU_NURBS_ERROR23',
    'GLU_NURBS_ERROR24',
    'GLU_NURBS_ERROR25',
    'GLU_NURBS_ERROR26',
    'GLU_NURBS_ERROR27',
    'GLU_NURBS_ERROR28',
    'GLU_NURBS_ERROR29',
    'GLU_NURBS_ERROR3',
    'GLU_NURBS_ERROR30',
    'GLU_NURBS_ERROR31',
    'GLU_NURBS_ERROR32',
    'GLU_NURBS_ERROR33',
    'GLU_NURBS_ERROR34',
    'GLU_NURBS_ERROR35',
    'GLU_NURBS_ERROR36',
    'GLU_NURBS_ERROR37',
    'GLU_NURBS_ERROR4',
    'GLU_NURBS_ERROR5',
    'GLU_NURBS_ERROR6',
    'GLU_NURBS_ERROR7',
    'GLU_NURBS_ERROR8',
    'GLU_NURBS_ERROR9',
    'GLU_NURBS_MODE',
    'GLU_NURBS_MODE_EXT',
    'GLU_NURBS_NORMAL',
    'GLU_NURBS_NORMAL_DATA',
    'GLU_NURBS_NORMAL_DATA_EXT',
    'GLU_NURBS_NORMAL_EXT',
    'GLU_NURBS_RENDERER',
    'GLU_NURBS_RENDERER_EXT',
    'GLU_NURBS_TESSELLATOR',
    'GLU_NURBS_TESSELLATOR_EXT',
    'GLU_NURBS_TEXTURE_COORD',
    'GLU_NURBS_TEXTURE_COORD_DATA',
    'GLU_NURBS_TEX_COORD_DATA_EXT',
    'GLU_NURBS_TEX_COORD_EXT',
    'GLU_NURBS_VERTEX',
    'GLU_NURBS_VERTEX_DATA',
    'GLU_NURBS_VERTEX_DATA_EXT',
    'GLU_NURBS_VERTEX_EXT',
    'GLU_OBJECT_PARAMETRIC_ERROR',
    'GLU_OBJECT_PARAMETRIC_ERROR_EXT',
    'GLU_OBJECT_PATH_LENGTH',
    'GLU_OBJECT_PATH_LENGTH_EXT',
    'GLU_OUTLINE_PATCH',
    'GLU_OUTLINE_POLYGON',
    'GLU_OUTSIDE',
    'GLU_OUT_OF_MEMORY',
    'GLU_PARAMETRIC_ERROR',
    'GLU_PARAMETRIC_TOLERANCE',
    'GLU_PATH_LENGTH',
    'GLU_POINT',
    'GLU_SAMPLING_METHOD',
    'GLU_SAMPLING_TOLERANCE',
    'GLU_SILHOUETTE',
    'GLU_SMOOTH',
    'GLU_TESS_BEGIN',
    'GLU_TESS_BEGIN_DATA',
    'GLU_TESS_BOUNDARY_ONLY',
    'GLU_TESS_COMBINE',
    'GLU_TESS_COMBINE_DATA',
    'GLU_TESS_COORD_TOO_LARGE',
    'GLU_TESS_EDGE_FLAG',
    'GLU_TESS_EDGE_FLAG_DATA',
    'GLU_TESS_END',
    'GLU_TESS_END_DATA',
    'GLU_TESS_ERROR',
    'GLU_TESS_ERROR1',
    'GLU_TESS_ERROR2',
    'GLU_TESS_ERROR3',
    'GLU_TESS_ERROR4',
    'GLU_TESS_ERROR5',
    'GLU_TESS_ERROR6',
    'GLU_TESS_ERROR7',
    'GLU_TESS_ERROR8',
    'GLU_TESS_ERROR_DATA',
    'GLU_TESS_MAX_COORD',
    'GLU_TESS_MISSING_BEGIN_CONTOUR',
    'GLU_TESS_MISSING_BEGIN_POLYGON',
    'GLU_TESS_MISSING_END_CONTOUR',
    'GLU_TESS_MISSING_END_POLYGON',
    'GLU_TESS_NEED_COMBINE_CALLBACK',
    'GLU_TESS_TOLERANCE',
    'GLU_TESS_VERTEX',
    'GLU_TESS_VERTEX_DATA',
    'GLU_TESS_WINDING_ABS_GEQ_TWO',
    'GLU_TESS_WINDING_NEGATIVE',
    'GLU_TESS_WINDING_NONZERO',
    'GLU_TESS_WINDING_ODD',
    'GLU_TESS_WINDING_POSITIVE',
    'GLU_TESS_WINDING_RULE',
    'GLU_TRUE',
    'GLU_UNKNOWN',
    'GLU_U_STEP',
    'GLU_VERSION',
    'GLU_VERSION_1_1',
    'GLU_VERSION_1_2',
    'GLU_VERSION_1_3',
    'GLU_VERTEX',
    'GLU_V_STEP'
]



'''OpenGL extension IBM.static_data

This module customises the behaviour of the 
OpenGL.raw.GL.IBM.static_data to provide a more 
Python-friendly API

Overview (from the spec)
	
	The OpenGL specification requires that data be bound at call time.	The
	IBM_static_data extension relaxes the bind-at-call semantics allowing
	an implementation to dereference pointers some time after the
	corresponding calls.
	
	Because of the bind-at-call sematics of standard OpenGL, an
	implementation is required to either copy or fully process data at the
	time it is provided by the application.  Copying data substantially
	increases the demands on the memory subsystem; processing the data may
	result in ineffective amortization of fixed costs.	Neither copying nor
	processing allows multiple rendering threads to operate on the original
	data.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/IBM/static_data.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.IBM.static_data import *
from OpenGL.raw.GL.IBM.static_data import _EXTENSION_NAME

def glInitStaticDataIBM():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension ARB.shading_language_packing

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shading_language_packing to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides the GLSL built-in functions to convert a 32-bit
	unsigned integer holding a pair of 16-bit floating-point values to or from
	a two-component floating-point vector (vec2).  
	
	This mechanism allows GLSL shaders to read and write 16-bit floating-point
	encodings (via 32-bit unsigned integers) without introducing a full set of
	16-bit floating-point data types.
	
	This extension also adds the GLSL built-in packing functions included in
	GLSL version 4.00 and the ARB_gpu_shader5 extension which pack and unpack
	vectors of small fixed-point data types into a larger scalar. By putting
	these packing functions in this separate extension it allows
	implementations to provide these functions in hardware that supports them
	independent of the other ARB_gpu_shader5 features.
	
	In addition to the packing functions from ARB_gpu_shader5 this extension
	also adds the missing [un]packSnorm2x16 for completeness.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shading_language_packing.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shading_language_packing import *
from OpenGL.raw.GL.ARB.shading_language_packing import _EXTENSION_NAME

def glInitShadingLanguagePackingARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension WIN.specular_fog

This module customises the behaviour of the 
OpenGL.raw.GL.WIN.specular_fog to provide a more 
Python-friendly API

Overview (from the spec)
	
	Specularly lit textures enhance the realism of a scene greatly.
	Using the current OpenGL lighting model, one cannot obtain specularly lit 
	textures. This is because in the current OpenGL lighting model lighting
	is done ahead of texturing and texture-functions such as modulate are 
	inadequate for such a simulation. What needs to be addressed is that, 
	somehow an additional interpolant (specular color of that material) needs 
	to be propagated till that stage of the pipeline where texture-mapping is
	performed. This interpolant is then added on to the fragment's color
	resulting from the texturing process before proceeding with the rest of 
	the pipeline.
	
	This can be addressed very easily in software, but hardware
	is not so malleable. Currently most hardware does not support such a
	
	lighting model. However, some current hardware does support fogging,
	which takes place in the pipeline after texturing. This hardware 
	assumes that the fog blend factor f is computed per-vertex and
	interpolates the value across the primitive. The WIN_specular_fog
	extension enables the use of such existing fog circuitry to obtain 
	specularly lit textures without much performance degradation. 
	
	To use it the programmer simply enables the extension with a call to
	Enable with the appropriate enumerant and sets the fog color to the 
	desired specular color.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/WIN/specular_fog.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.WIN.specular_fog import *
from OpenGL.raw.GL.WIN.specular_fog import _EXTENSION_NAME

def glInitSpecularFogWIN():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_NV_non_square_matrices'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_NV_non_square_matrices',error_checker=_errors._error_checker)
GL_FLOAT_MAT2x3_NV=_C('GL_FLOAT_MAT2x3_NV',0x8B65)
GL_FLOAT_MAT2x4_NV=_C('GL_FLOAT_MAT2x4_NV',0x8B66)
GL_FLOAT_MAT3x2_NV=_C('GL_FLOAT_MAT3x2_NV',0x8B67)
GL_FLOAT_MAT3x4_NV=_C('GL_FLOAT_MAT3x4_NV',0x8B68)
GL_FLOAT_MAT4x2_NV=_C('GL_FLOAT_MAT4x2_NV',0x8B69)
GL_FLOAT_MAT4x3_NV=_C('GL_FLOAT_MAT4x3_NV',0x8B6A)
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2x3fvNV(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix2x4fvNV(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3x2fvNV(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix3x4fvNV(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4x2fvNV(location,count,transpose,value):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLsizei,_cs.GLboolean,arrays.GLfloatArray)
def glUniformMatrix4x3fvNV(location,count,transpose,value):pass



'''OpenGL extension VERSION.GLES3_3_0

This module customises the behaviour of the 
OpenGL.raw.GLES3.VERSION.GLES3_3_0 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GLES3_3_0.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES3 import _types, _glgets
from OpenGL.raw.GLES3.VERSION.GLES3_3_0 import *
from OpenGL.raw.GLES3.VERSION.GLES3_3_0 import _EXTENSION_NAME

def glInitGles330VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawRangeElements.indices size not checked against 'count,type'
glDrawRangeElements=wrapper.wrapper(glDrawRangeElements).setInputArraySize(
    'indices', None
)
# INPUT glTexImage3D.pixels size not checked against 'format,type,width,height,depth'
glTexImage3D=wrapper.wrapper(glTexImage3D).setInputArraySize(
    'pixels', None
)
# INPUT glTexSubImage3D.pixels size not checked against 'format,type,width,height,depth'
glTexSubImage3D=wrapper.wrapper(glTexSubImage3D).setInputArraySize(
    'pixels', None
)
# INPUT glCompressedTexImage3D.data size not checked against imageSize
glCompressedTexImage3D=wrapper.wrapper(glCompressedTexImage3D).setInputArraySize(
    'data', None
)
# INPUT glCompressedTexSubImage3D.data size not checked against imageSize
glCompressedTexSubImage3D=wrapper.wrapper(glCompressedTexSubImage3D).setInputArraySize(
    'data', None
)
glGenQueries=wrapper.wrapper(glGenQueries).setOutput(
    'ids',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
# INPUT glDeleteQueries.ids size not checked against n
glDeleteQueries=wrapper.wrapper(glDeleteQueries).setInputArraySize(
    'ids', None
)
glGetQueryiv=wrapper.wrapper(glGetQueryiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetQueryObjectuiv=wrapper.wrapper(glGetQueryObjectuiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetBufferPointerv=wrapper.wrapper(glGetBufferPointerv).setOutput(
    'params',size=(1,),orPassIn=True
)
# INPUT glDrawBuffers.bufs size not checked against n
glDrawBuffers=wrapper.wrapper(glDrawBuffers).setInputArraySize(
    'bufs', None
)
# INPUT glUniformMatrix2x3fv.value size not checked against count*6
glUniformMatrix2x3fv=wrapper.wrapper(glUniformMatrix2x3fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x2fv.value size not checked against count*6
glUniformMatrix3x2fv=wrapper.wrapper(glUniformMatrix3x2fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix2x4fv.value size not checked against count*8
glUniformMatrix2x4fv=wrapper.wrapper(glUniformMatrix2x4fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x2fv.value size not checked against count*8
glUniformMatrix4x2fv=wrapper.wrapper(glUniformMatrix4x2fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix3x4fv.value size not checked against count*12
glUniformMatrix3x4fv=wrapper.wrapper(glUniformMatrix3x4fv).setInputArraySize(
    'value', None
)
# INPUT glUniformMatrix4x3fv.value size not checked against count*12
glUniformMatrix4x3fv=wrapper.wrapper(glUniformMatrix4x3fv).setInputArraySize(
    'value', None
)
# INPUT glDeleteVertexArrays.arrays size not checked against n
glDeleteVertexArrays=wrapper.wrapper(glDeleteVertexArrays).setInputArraySize(
    'arrays', None
)
glGenVertexArrays=wrapper.wrapper(glGenVertexArrays).setOutput(
    'arrays',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetIntegeri_v=wrapper.wrapper(glGetIntegeri_v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
# INPUT glTransformFeedbackVaryings.varyings size not checked against count
glTransformFeedbackVaryings=wrapper.wrapper(glTransformFeedbackVaryings).setInputArraySize(
    'varyings', None
)
glGetTransformFeedbackVarying=wrapper.wrapper(glGetTransformFeedbackVarying).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'name',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'size',size=(1,),orPassIn=True
).setOutput(
    'type',size=(1,),orPassIn=True
)
# INPUT glVertexAttribIPointer.pointer size not checked against 'size,type,stride'
glVertexAttribIPointer=wrapper.wrapper(glVertexAttribIPointer).setInputArraySize(
    'pointer', None
)
glGetVertexAttribIiv=wrapper.wrapper(glGetVertexAttribIiv).setOutput(
    'params',size=(1,),orPassIn=True
)
glGetVertexAttribIuiv=wrapper.wrapper(glGetVertexAttribIuiv).setOutput(
    'params',size=(1,),orPassIn=True
)
glVertexAttribI4iv=wrapper.wrapper(glVertexAttribI4iv).setInputArraySize(
    'v', 4
)
glVertexAttribI4uiv=wrapper.wrapper(glVertexAttribI4uiv).setInputArraySize(
    'v', 4
)
# OUTPUT glGetUniformuiv.params COMPSIZE(program, location) 
# INPUT glGetFragDataLocation.name size not checked against 'name'
glGetFragDataLocation=wrapper.wrapper(glGetFragDataLocation).setInputArraySize(
    'name', None
)
# INPUT glUniform1uiv.value size not checked against count
glUniform1uiv=wrapper.wrapper(glUniform1uiv).setInputArraySize(
    'value', None
)
# INPUT glUniform2uiv.value size not checked against count*2
glUniform2uiv=wrapper.wrapper(glUniform2uiv).setInputArraySize(
    'value', None
)
# INPUT glUniform3uiv.value size not checked against count*3
glUniform3uiv=wrapper.wrapper(glUniform3uiv).setInputArraySize(
    'value', None
)
# INPUT glUniform4uiv.value size not checked against count*4
glUniform4uiv=wrapper.wrapper(glUniform4uiv).setInputArraySize(
    'value', None
)
# INPUT glClearBufferiv.value size not checked against 'buffer'
glClearBufferiv=wrapper.wrapper(glClearBufferiv).setInputArraySize(
    'value', None
)
# INPUT glClearBufferuiv.value size not checked against 'buffer'
glClearBufferuiv=wrapper.wrapper(glClearBufferuiv).setInputArraySize(
    'value', None
)
# INPUT glClearBufferfv.value size not checked against 'buffer'
glClearBufferfv=wrapper.wrapper(glClearBufferfv).setInputArraySize(
    'value', None
)
# INPUT glGetUniformIndices.uniformNames size not checked against 'uniformCount'
glGetUniformIndices=wrapper.wrapper(glGetUniformIndices).setOutput(
    'uniformIndices',size=_glgets._glget_size_mapping,pnameArg='uniformCount',orPassIn=True
).setInputArraySize(
    'uniformNames', None
)
# OUTPUT glGetActiveUniformsiv.params COMPSIZE(uniformCount, pname) 
# INPUT glGetActiveUniformsiv.uniformIndices size not checked against uniformCount
glGetActiveUniformsiv=wrapper.wrapper(glGetActiveUniformsiv).setInputArraySize(
    'uniformIndices', None
)
# INPUT glGetUniformBlockIndex.uniformBlockName size not checked against ''
glGetUniformBlockIndex=wrapper.wrapper(glGetUniformBlockIndex).setInputArraySize(
    'uniformBlockName', None
)
# OUTPUT glGetActiveUniformBlockiv.params COMPSIZE(program, uniformBlockIndex, pname) 
glGetActiveUniformBlockName=wrapper.wrapper(glGetActiveUniformBlockName).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'uniformBlockName',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
# INPUT glDrawElementsInstanced.indices size not checked against 'count,type'
glDrawElementsInstanced=wrapper.wrapper(glDrawElementsInstanced).setInputArraySize(
    'indices', None
)
glGetInteger64v=wrapper.wrapper(glGetInteger64v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetSynciv=wrapper.wrapper(glGetSynciv).setOutput(
    'length',size=(1,),orPassIn=True
).setOutput(
    'values',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
glGetInteger64i_v=wrapper.wrapper(glGetInteger64i_v).setOutput(
    'data',size=_glgets._glget_size_mapping,pnameArg='target',orPassIn=True
)
glGetBufferParameteri64v=wrapper.wrapper(glGetBufferParameteri64v).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGenSamplers=wrapper.wrapper(glGenSamplers).setOutput(
    'samplers',size=lambda x:(x,),pnameArg='count',orPassIn=True
)
# INPUT glDeleteSamplers.samplers size not checked against count
glDeleteSamplers=wrapper.wrapper(glDeleteSamplers).setInputArraySize(
    'samplers', None
)
# INPUT glSamplerParameteriv.param size not checked against 'pname'
glSamplerParameteriv=wrapper.wrapper(glSamplerParameteriv).setInputArraySize(
    'param', None
)
# INPUT glSamplerParameterfv.param size not checked against 'pname'
glSamplerParameterfv=wrapper.wrapper(glSamplerParameterfv).setInputArraySize(
    'param', None
)
glGetSamplerParameteriv=wrapper.wrapper(glGetSamplerParameteriv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
glGetSamplerParameterfv=wrapper.wrapper(glGetSamplerParameterfv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
# INPUT glDeleteTransformFeedbacks.ids size not checked against n
glDeleteTransformFeedbacks=wrapper.wrapper(glDeleteTransformFeedbacks).setInputArraySize(
    'ids', None
)
glGenTransformFeedbacks=wrapper.wrapper(glGenTransformFeedbacks).setOutput(
    'ids',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
glGetProgramBinary=wrapper.wrapper(glGetProgramBinary).setOutput(
    'binary',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
).setOutput(
    'binaryFormat',size=(1,),orPassIn=True
).setOutput(
    'length',size=(1,),orPassIn=True
)
# INPUT glProgramBinary.binary size not checked against length
glProgramBinary=wrapper.wrapper(glProgramBinary).setInputArraySize(
    'binary', None
)
# INPUT glInvalidateFramebuffer.attachments size not checked against numAttachments
glInvalidateFramebuffer=wrapper.wrapper(glInvalidateFramebuffer).setInputArraySize(
    'attachments', None
)
# INPUT glInvalidateSubFramebuffer.attachments size not checked against numAttachments
glInvalidateSubFramebuffer=wrapper.wrapper(glInvalidateSubFramebuffer).setInputArraySize(
    'attachments', None
)
glGetInternalformativ=wrapper.wrapper(glGetInternalformativ).setOutput(
    'params',size=lambda x:(x,),pnameArg='bufSize',orPassIn=True
)
### END AUTOGENERATED SECTION




'''OpenGL extension ARB.texture_env_combine

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.texture_env_combine to provide a more 
Python-friendly API

Overview (from the spec)
	
	New texture environment function COMBINE_ARB allows programmable
	texture combiner operations, including:
	
	    REPLACE                 Arg0
	    MODULATE                Arg0 * Arg1
	    ADD                     Arg0 + Arg1
	    ADD_SIGNED_ARB          Arg0 + Arg1 - 0.5
	    SUBTRACT_ARB            Arg0 - Arg1
	    INTERPOLATE_ARB         Arg0 * (Arg2) + Arg1 * (1-Arg2)
	
	where Arg0, Arg1 and Arg2 are derived from
	
	    PRIMARY_COLOR_ARB       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_ARB            texture environment constant color
	    PREVIOUS_ARB            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_ARB
	
	In addition, the result may be scaled by 1.0, 2.0 or 4.0.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/texture_env_combine.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.texture_env_combine import *
from OpenGL.raw.GL.ARB.texture_env_combine import _EXTENSION_NAME

def glInitTextureEnvCombineARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION